@@ -11,7 +11,7 @@ use base qw(DynaLoader);
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '3.212';
+$VERSION = '3.230';
 
 ######################################################################
 #### Configuration Section
@@ -21,6 +21,7 @@ bootstrap Verilog::Preproc;
 #In Preproc.xs:
 # sub _new (class, keepcmt, linedir, pedantic)
 # sub _open (class)
+# sub getall (class)
 # sub getline (class)
 # sub eof (class)
 # sub filename (class)
@@ -53,6 +54,11 @@ sub new {
     return $self;
 }
 
+sub DESTROY {
+    my $self = shift;
+    $self->_DESTROY;
+}
+
 sub open {
     my $self = shift;
     my %params = (
@@ -140,6 +146,10 @@ sub undef {
     my $self = shift;
     $self->{options}->undef(@_);
 }
+sub undefineall {
+    my $self = shift;
+    $self->{options}->undefineall(@_);
+}
 sub define {
     my $self = shift;
     #print "DEFINE @_\n";
@@ -199,12 +209,13 @@ Verilog::Preproc - Preprocess Verilog files
 =head1 DESCRIPTION
 
 Verilog::Preproc reads Verilog files, and preprocesses them according to
-the SystemVerilog 2005 specification.  Programs can be easily converted
-from reading a IO::File into reading preprocessed output from
+the SystemVerilog 2009 (1800-2009) specification which is the most recent
+extension of SystemVerilog 2005 (1800-2005).  Programs can be easily
+converted from reading a IO::File into reading preprocessed output from
 Verilog::Preproc.
 
-See the "Which Package" section of L<Verilog::Language> if you are unsure
-which parsing package to use for a new application.
+See the "Which Package" section of L<Verilog-Perl> if you are unsure which
+parsing package to use for a new application.
 
 =head1 MEMBER FUNCTIONS
 
@@ -219,6 +230,11 @@ Returns true at the end of the file.
 Returns the filename of the most recently returned getline().  May not match
 the filename passed on the command line, as `line directives are honored.
 
+=item $self->getall()
+
+Return the entire translated text up to the final EOF, similar to calling
+join('',$self->getline) but significantly faster.  Returns undef at EOF.
+
 =item $self->getline()
 
 Return the next line of text.  Returns undef at EOF.  (Just like
@@ -291,9 +307,11 @@ classes may be used, as long as their interface matches that of Getopt.
 
 =item pedantic=>1
 
-With pedantic set, rigorously obey the Verilog pedantic.  This disables
-the `__FILE__ and `__LINE__ features, and may disable other features that
-are not specified in the language pedantic. Defaults false.
+With pedantic set, rigorously obey the Verilog pedantic.  This used to
+disable the `__FILE__ and `__LINE__ features but no longer does as they
+were added to the 1800-2009 standard.  It remains to disable `error and may
+disable other future features that are not specified in the language
+standard. Defaults false.
 
 =back
 
@@ -313,6 +331,10 @@ do nothing.
 
 Called with each `undef.  Defaults to use options object.
 
+=item $self->undefineall()
+
+Called with each `undefineall.  Defaults to use options object.
+
 =item $self->define(I<defname>, I<value>, I<params>)
 
 Called with each `define.  Defaults to use options object.
@@ -350,21 +372,27 @@ after resolving the filename with the options parameter.
 
 =head1 COMPLIANCE
 
-The preprocessor supports the constructs defined in the Verilog 2005 and
-SystemVerilog 2005 standards.
+The preprocessor supports the constructs defined in the SystemVerilog 2009
+standard (IEEE 1800-2009), which is a superset of Verilog 1995 (IEEE
+1364-1995), Verilog 2001 (IEEE 1364-2001), Verilog 2005 (IEEE 1364-2005)
+and SystemVerilog 2005 (IEEE 1800-2005).
 
-Verilog::Preproc adds the following features (unless the pedantic parameter
-is set.):
+Verilog::Preproc adds the `error macro (unless the pedantic parameter is
+set.):
 
 =over 4
 
 =item `__FILE__
 
-`__FILE__ will be replaced by the current filename. (Like C++ __FILE__.)
+The __FILE__ define expands to the current filename as a string, like C++'s
+__FILE__.  This was incorporated into to the 1800-2009 standard (but
+supported by Verilog-Perl since 2004!)
 
 =item `__LINE__
 
-`__LINE__  will be replaced by the current line number. (Like C++ __LINE__.)
+The __LINE__ define expands to the current filename as a string, like C++'s
+__LINE__.  This was incorporated into to the 1800-2009 standard (but
+supported by Verilog-Perl since 2004!)
 
 =item `error I<"string">
 
@@ -380,7 +408,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2009 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
